<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Fri Jan 01 2021 02:21:01 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issue with post-processing via API v1 cmd
  ([7d436fab](https://gitlab-ci-token:2BnK88itKmnHV_9uSsHE@git.sickrage.ca/SiCKRAGE/sickrage/commit/7d436fabd5742d185592e1de6c6b05d4cadd6615))
  - Fixed issue with json encoding when returning errors from API v1 that has byte encoding
  ([20e0a1c0](https://gitlab-ci-token:2BnK88itKmnHV_9uSsHE@git.sickrage.ca/SiCKRAGE/sickrage/commit/20e0a1c0e7a561b0bbc611abdbd5695426156a9e))
  - Fixed issue with forcing backlog for specific shows and passing of the series provider ID
  ([5f4ad575](https://gitlab-ci-token:2BnK88itKmnHV_9uSsHE@git.sickrage.ca/SiCKRAGE/sickrage/commit/5f4ad5752d4192d2ddc6bcca70e179fd6c21ebfb))




